powered by
Calculate the Bass probability density function of purchase f(t)
npdsim_bass(p_param, q_param, t)
A numeric vector of the probability density function of purchase at time t, f(t)
Coefficient of innovation
Coefficient of imitation
A numeric vector of time periods
npdsim_bass(p_param=0.01,q_param=0.2, t=1:20)
Run the code above in your browser using DataLab